@@ -17,6 +17,8 @@ genome.fasta.gz
 pasa_assemblies.fasta.gz
 pasa_assemblies.gff3.gz
 runMe.sh
+pasa_assemblies_described.txt.gz
+Makefile
                         );
 
 
@@ -33,6 +35,7 @@ foreach my $file (<*>) {
 
 
 `rm -rf ./pasa_assemblies.fasta.transdecoder_dir/`;
+`rm -rf ./pasa_assemblies.fasta.transdecoder_dir.__checkpoints`;
 
 
 exit(0);
