@@ -15,6 +15,8 @@ my @files_to_keep = qw (
 cleanme.pl
 runMe.sh
 Trinity.fasta.gz
+Makefile
+genome_alignments.gmap.gff3.gz
                         );
 
 
@@ -31,6 +33,6 @@ foreach my $file (<*>) {
 
 
 `rm -rf ./Trinity.fasta.transdecoder_dir/`;
-
+`rm -rf ./Trinity.fasta.transdecoder_dir.__checkpoints`;
 
 exit(0);
